@@ -5,9 +5,9 @@
 package Data::Dump::Color;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-23'; # DATE
+our $DATE = '2021-06-24'; # DATE
 our $DIST = 'Data-Dump-Color'; # DIST
-our $VERSION = '0.246'; # VERSION
+our $VERSION = '0.247'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -90,7 +90,7 @@ sub dump
         {ns_prefixes=>['ColorTheme::Data::Dump::Color','ColorTheme','']}, $COLOR_THEME);
     require Data::Dump::FilterContext if @FILTERS;
 
-    my $name = "a";
+    my $name = "var";
     my @dump;
     my @cdump;
 
@@ -267,9 +267,10 @@ sub _dump
                 "do{my \$fix}",
                 _col(keyword=>"do")."{"._col(keyword=>"my")." "._col(symbol=>"\$fix")."}",
             ) if @$idx && $idx->[-1] eq '$';
-	    return (
-                "'fix'",
-                _col(string => "'fix'"),
+	    my $str = squote($sref);
+            return (
+                $str,
+                _col(string => $str),
             );
 	}
 	$seen{$id} = [$name, $idx];
@@ -603,8 +604,8 @@ sub fullname
 	    $cname .= $i->[1];
 	    $last_was_index++;
 	} else {
-	    $name  .= "->" unless $last_was_index++;
-	    $cname .= "->" unless $last_was_index++;
+	    $name  .= "->";
+	    $cname .= "->";
 	    $name  .= $i->[0];
 	    $cname .= $i->[1];
 	}
@@ -761,6 +762,13 @@ sub quote {
   return qq("$_");
 }
 
+# put a string value in single quotes
+sub squote {
+    local($_) = $_[0];
+    s/([\\'])/\\$1/g;
+    return qq('$_');
+}
+
 1;
 # ABSTRACT: Like Data::Dump, but with color
 
@@ -776,7 +784,7 @@ Data::Dump::Color - Like Data::Dump, but with color
 
 =head1 VERSION
 
-This document describes version 0.246 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-23.
+This document describes version 0.247 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-24.
 
 =head1 SYNOPSIS
 
@@ -793,7 +801,7 @@ index, depth indicator, and so on.
 For more information, see Data::Dump. This documentation explains what's
 different between this module and Data::Dump.
 
-=for Pod::Coverage ^(dumpf|pp|quote|tied_str|fullname|format_list|str|looks_like_number|max)$
+=for Pod::Coverage ^(dumpf|pp|quote|squote|tied_str|fullname|format_list|str|looks_like_number|max)$
 
 =head1 RESULTS
 
